==> ssp-center-api-1.1.39-yqf-20230128.065614-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ProgrammaticMediaReportHisRspDTO.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import lombok.Data;

import java.io.Serializable;
import java.util.List;

/**
 * @Author yuquanfeng
 * @Date 2022/4/11
 * @Description
 * @Param
 * @return
 **/
@Data
public class ProgrammaticMediaReportHisRspDTO implements Serializable {
    private static final long serialVersionUID = 1L;

    private Long id;
    /**
     * 广告位id
     */
    private Long slotId;
    /**
     * 平台id
     */
    private Integer mediaPlatform;
    /**
     * 账户id
     */
    private String accountId;
    /**
     * 策略id
     */
    private Integer strategyId;
    /**
     * 备注
     */
    private String remark;
    /**
     * 配置列表
     */
    private List<ProgrammaticMediaReportConfigHisDTO> reportConfigList;
    /**
     * 操作人id
     */
    private Long operateId;
    /**
     * 操作人名称
     */
    private String operateName;
    /**
     * 扩展字段 百度-token
     */
    private String extendValue;
    /**
     * srcId vivo特有
     */
    private String srcId;

    /**
     * 360 key
     */
    private String api360Key;
    /**
     * 360 secret
     */
    private String api360Secret;
    /**
     * 万能wifi钥匙 客户ID
     */
    private String wnClientId;

    /**
     * 万能wifi钥匙 签名密钥
     */
    private String wnSecretkey;

    /**
     * vivo clientId
     */
    private String clientId;
    /**
     * vivo clientSecret
     */
    private String clientSecret;
    /**
     * 固定收益
     */
    private Long income;

    /**
     * oppo api_id
     */
    private String apiId;
    /**
     * oppo api_key
     */
    private String apiKey;

    /**
     * sina 转化ID
     */
    private String convId;
    /**
     * sina token
     */
    private String token;

    /**
     * youku appKey
     */
    private String appKey;

}

==> ssp-center-api-1.2.27-yqf-20240711.013158-3-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ProgrammaticMediaReportHisRspDTO.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import lombok.Data;

import java.io.Serializable;
import java.util.List;

/**
 * @Author yuquanfeng
 * @Date 2022/4/11
 * @Description
 * @Param
 * @return
 **/
@Data
public class ProgrammaticMediaReportHisRspDTO implements Serializable {
    private static final long serialVersionUID = 1L;

    private Long id;
    /**
     * 广告位id
     */
    private Long slotId;
    /**
     * 平台id
     */
    private Integer mediaPlatform;
    /**
     * 账户id
     */
    private String accountId;
    /**
     * 策略id
     */
    private Integer strategyId;
    /**
     * 备注
     */
    private String remark;
    /**
     * 配置列表
     */
    private List<ProgrammaticMediaReportConfigHisDTO> reportConfigList;
    /**
     * 操作人id
     */
    private Long operateId;
    /**
     * 操作人名称
     */
    private String operateName;
    /**
     * 扩展字段 百度-token
     */
    private String extendValue;
    /**
     * srcId vivo特有
     */
    private String srcId;

    /**
     * 360 key
     */
    private String api360Key;
    /**
     * 360 secret
     */
    private String api360Secret;
    /**
     * 万能wifi钥匙 客户ID
     */
    private String wnClientId;

    /**
     * 万能wifi钥匙 签名密钥
     */
    private String wnSecretkey;

    /**
     * vivo clientId
     */
    private String clientId;
    /**
     * vivo clientSecret
     */
    private String clientSecret;
    /**
     * 固定收益
     */
    private Long income;

    /**
     * oppo api_id
     */
    private String apiId;
    /**
     * oppo api_key
     */
    private String apiKey;

    /**
     * sina 转化ID
     */
    private String convId;
    /**
     * sina token
     */
    private String token;

    /**
     * youku appKey
     */
    private String appKey;

    /**
     * 凤凰网转化id
     */
    private String fenghuangConvertId;
    /**
     * 凤凰网加密密钥
     */
    private String fenghuangSecretKey;


    private String alipayAppId;

    private String alipayToken;

    private String alipayTag;

    private String alipayPath;

    private String advertKey;
}
